@@ -139,10 +139,10 @@ class IT600Gateway:
                     precision=0.5,
                     current_temperature=th["LocalTemperature_x100"] / 100,
                     target_temperature=th["HeatingSetpoint_x100"] / 100,
-                    max_temp=35 if "MaxHeatSetpoint_x100" not in th else th["MaxHeatSetpoint_x100"] / 100,
-                    min_temp=5 if "MinHeatSetpoint_x100" not in th else th["MinHeatSetpoint_x100"] / 100,
+                    max_temp=th.get("MaxHeatSetpoint_x100", 3500) / 100,
+                    min_temp=th.get("MinHeatSetpoint_x100", 500) / 100,
                     hvac_mode=HVAC_MODE_OFF if th["HoldType"] == 7 else HVAC_MODE_HEAT,
-                    hvac_action=CURRENT_HVAC_OFF if th["HoldType"] == 7 else CURRENT_HVAC_HEAT if th["RunningState"] == 1 else CURRENT_HVAC_IDLE,
+                    hvac_action=CURRENT_HVAC_OFF if th["HoldType"] == 7 else CURRENT_HVAC_IDLE if th["RunningState"] == 0 else CURRENT_HVAC_HEAT,
                     hvac_modes=[HVAC_MODE_OFF, HVAC_MODE_HEAT],
                     preset_mode=PRESET_OFF if th["HoldType"] == 7 else PRESET_PERMANENT_HOLD if th["HoldType"] == 2 else PRESET_FOLLOW_SCHEDULE,
                     preset_modes=[PRESET_FOLLOW_SCHEDULE, PRESET_PERMANENT_HOLD, PRESET_OFF],
